Struct ApproveCustodianStudyAccessRequest
pub struct ApproveCustodianStudyAccessRequest {
pub datastore_id: Uuid,
pub request_id: Uuid,
}Expand description
Application-safe input for approving a pending Study access request.
Fields
datastore_id: Uuidrequest_id: UuidTrait Implementations
impl Clone for ApproveCustodianStudyAccessRequest
impl Clone for ApproveCustodianStudyAccessRequest
fn clone(&self) -> ApproveCustodianStudyAccessRequest
fn clone(&self) -> ApproveCustodianStudyAccessRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for ApproveCustodianStudyAccessRequest
impl Debug for ApproveCustodianStudyAccessRequest
impl PartialEq for ApproveCustodianStudyAccessRequest
impl PartialEq for ApproveCustodianStudyAccessRequest
fn eq(&self, other: &ApproveCustodianStudyAccessRequest) -> bool
fn eq(&self, other: &ApproveCustodianStudyAccessRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for ApproveCustodianStudyAccessRequest
impl Eq for ApproveCustodianStudyAccessRequest
impl StructuralPartialEq for ApproveCustodianStudyAccessRequest