Struct CustodianStudyAccessRequestDecision
pub struct CustodianStudyAccessRequestDecision {
pub decided_at: Option<DateTime<Utc>>,
pub decided_by: Option<String>,
pub reason: Option<String>,
}Expand description
Decision facts visible to a custodian reviewing a Study access request.
Fields
decided_at: Option<DateTime<Utc>>decided_by: Option<String>reason: Option<String>Trait Implementations
impl Clone for CustodianStudyAccessRequestDecision
impl Clone for CustodianStudyAccessRequestDecision
fn clone(&self) -> CustodianStudyAccessRequestDecision
fn clone(&self) -> CustodianStudyAccessRequestDecision
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl PartialEq for CustodianStudyAccessRequestDecision
impl PartialEq for CustodianStudyAccessRequestDecision
fn eq(&self, other: &CustodianStudyAccessRequestDecision) -> bool
fn eq(&self, other: &CustodianStudyAccessRequestDecision) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CustodianStudyAccessRequestDecision
impl StructuralPartialEq for CustodianStudyAccessRequestDecision