Struct ProvisionStudyAccessRequestWorkflowEntry
pub struct ProvisionStudyAccessRequestWorkflowEntry {
pub datastore_id: Uuid,
pub requester_orcid: String,
}Expand description
Input for provisioning the requester with datastore workflow entry.
Fields
datastore_id: Uuidrequester_orcid: StringTrait Implementations
impl Clone for ProvisionStudyAccessRequestWorkflowEntry
impl Clone for ProvisionStudyAccessRequestWorkflowEntry
fn clone(&self) -> ProvisionStudyAccessRequestWorkflowEntry
fn clone(&self) -> ProvisionStudyAccessRequestWorkflowEntry
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl PartialEq for ProvisionStudyAccessRequestWorkflowEntry
impl PartialEq for ProvisionStudyAccessRequestWorkflowEntry
fn eq(&self, other: &ProvisionStudyAccessRequestWorkflowEntry) -> bool
fn eq(&self, other: &ProvisionStudyAccessRequestWorkflowEntry) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ProvisionStudyAccessRequestWorkflowEntry
impl StructuralPartialEq for ProvisionStudyAccessRequestWorkflowEntry