pub enum BrowserDictionaryDiscoveryError {
InvalidReference(Box<ProtocolError>),
InvalidDatastoreIdentity,
DatastoreUnavailable,
AuthorityUnavailable,
StudyNotFound,
ResourceNotFound,
DataFileDictionaryUnsupported,
}Expand description
Closed workflow failures returned by browser dictionary discovery.
Variants
InvalidReference(Box<ProtocolError>)
A resource reference has the wrong kind or Datastore origin.
InvalidDatastoreIdentity
The supplied public datastore identifier is not a ready datastore.
The selected datastore metadata connection could not be used.
The configured dictionary discovery capability could not be resolved.
StudyNotFound
The selected study does not exist in the datastore.
ResourceNotFound
The selected dataset or datafile does not exist in the study.
DataFileDictionaryUnsupported
Legacy Datafile dictionary requests no longer have a successful shape.