pub fn datafile_list_response(
session: SessionStatusPayload,
result: DataFileListResult,
) -> DataFileListResponseExpand description
Projects one app-owned Datafile list outcome into the stable public result.
pub fn datafile_list_response(
session: SessionStatusPayload,
result: DataFileListResult,
) -> DataFileListResponseProjects one app-owned Datafile list outcome into the stable public result.