pub fn dataset_metadata_response(
session: SessionStatusPayload,
result: DatasetMetadataResult,
) -> DatasetMetadataResponseExpand description
Projects one app-owned Dataset metadata read into the stable public result.
pub fn dataset_metadata_response(
session: SessionStatusPayload,
result: DatasetMetadataResult,
) -> DatasetMetadataResponseProjects one app-owned Dataset metadata read into the stable public result.