pub fn domain_add_response(
session: SessionStatusPayload,
result: DomainAddResult,
) -> DomainAddResponseExpand description
Projects one app-owned Domain add outcome into the stable public result.
pub fn domain_add_response(
session: SessionStatusPayload,
result: DomainAddResult,
) -> DomainAddResponseProjects one app-owned Domain add outcome into the stable public result.