pub fn study_add_response(
session: SessionStatusPayload,
result: StudyAddResult,
) -> StudyAddResponseExpand description
Projects one app-owned Study add outcome into the stable public result.
pub fn study_add_response(
session: SessionStatusPayload,
result: StudyAddResult,
) -> StudyAddResponseProjects one app-owned Study add outcome into the stable public result.