pub fn study_list_response(
session: SessionStatusPayload,
result: StudyListResult,
) -> StudyListResponseExpand description
Projects one app-owned Study list outcome into the stable public result.
pub fn study_list_response(
session: SessionStatusPayload,
result: StudyListResult,
) -> StudyListResponseProjects one app-owned Study list outcome into the stable public result.