pub fn workflow_lineage(
datastore_id: PublicUuid,
value: TransformationLineageRecord,
) -> TransformationSummaryExpand description
The same canonical lineage shape is used by standalone and nested workflows.
pub fn workflow_lineage(
datastore_id: PublicUuid,
value: TransformationLineageRecord,
) -> TransformationSummaryThe same canonical lineage shape is used by standalone and nested workflows.