pub struct SemanticDeleteTargetIdentity {
pub domain_id: DomainId,
pub kind: SemanticDeleteTargetKind,
pub id: String,
pub domain: Option<String>,
pub name: String,
}Fields
domain_id: DomainIdResolved owning Domain identity, retained separately from display names.
kind: SemanticDeleteTargetKindid: Stringdomain: Option<String>name: StringTrait Implementations
Sourceimpl Clone for SemanticDeleteTargetIdentity
impl Clone for SemanticDeleteTargetIdentity
Sourcefn clone(&self) -> SemanticDeleteTargetIdentity
fn clone(&self) -> SemanticDeleteTargetIdentity
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SemanticDeleteTargetIdentity
impl Debug for SemanticDeleteTargetIdentity
Sourceimpl<'de> Deserialize<'de> for SemanticDeleteTargetIdentity
impl<'de> Deserialize<'de> for SemanticDeleteTargetIdentity
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for SemanticDeleteTargetIdentity
impl PartialEq for SemanticDeleteTargetIdentity
Sourcefn eq(&self, other: &SemanticDeleteTargetIdentity) -> bool
fn eq(&self, other: &SemanticDeleteTargetIdentity) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for SemanticDeleteTargetIdentity
impl StructuralPartialEq for SemanticDeleteTargetIdentity