BrowserDataFileMetadataSource

Struct BrowserDataFileMetadataSource 

pub struct BrowserDataFileMetadataSource {
    pub datafile_id: VersionId,
    pub format: String,
    pub size_bytes: Option<u64>,
    pub compressed: Option<bool>,
    pub encrypted: Option<bool>,
}
Narrow Datafile facts allowed to cross from the runtime adapter into the application workflow. Storage, digest, key, content, and preview facts cannot be represented here.

Fields

datafile_id: VersionIdformat: Stringsize_bytes: Option<u64>

Size in bytes of the managed stored artifact, when known.

compressed: Option<bool>encrypted: Option<bool>