pub struct BrowserDataFileMetadataSource {
pub datafile_id: VersionId,
pub format: String,
pub size_bytes: Option<u64>,
pub compressed: Option<bool>,
pub encrypted: Option<bool>,
}Expand description
Narrow Datafile facts allowed to cross from the runtime adapter into the application workflow. Storage, digest, key, content, and preview facts cannot be represented here.
Fields
datafile_id: VersionIdformat: Stringsize_bytes: Option<u64>Size in bytes of the managed stored artifact, when known.
compressed: Option<bool>encrypted: Option<bool>Trait Implementations
Sourceimpl Clone for BrowserDataFileMetadataSource
impl Clone for BrowserDataFileMetadataSource
Sourcefn clone(&self) -> BrowserDataFileMetadataSource
fn clone(&self) -> BrowserDataFileMetadataSource
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for BrowserDataFileMetadataSource
impl PartialEq for BrowserDataFileMetadataSource
Sourcefn eq(&self, other: &BrowserDataFileMetadataSource) -> bool
fn eq(&self, other: &BrowserDataFileMetadataSource) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for BrowserDataFileMetadataSource
impl StructuralPartialEq for BrowserDataFileMetadataSource